==> ctemplate-0.7.tar.gz: ctemplate-0.7/src/windows/google/template_pathops.h <==
// Copyright (c) 2007, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// ---
// Author: Craig Silverstein

#ifndef TEMPLATE_TEMPLATE_PATHOPS_H__
#define TEMPLATE_TEMPLATE_PATHOPS_H__

#include <string>

// These functions are all for internal use (hence the extra
// namespace), so no need to worry about dll-exporting for windows.

// NOTE: if you are statically linking the template library into your binary
// (rather than using the template .dll), set '/D CTEMPLATE_DLL_DECL='
// as a compiler flag in your project file to turn off the dllimports.
#ifndef CTEMPLATE_DLL_DECL
# define CTEMPLATE_DLL_DECL  __declspec(dllimport)
#endif

namespace google {

namespace ctemplate {

extern CTEMPLATE_DLL_DECL const char kCWD[];       // equivalent to "./"
extern CTEMPLATE_DLL_DECL const char kRootdir[];   // equivalent to "/"

std::string CTEMPLATE_DLL_DECL PathJoin(const std::string& a,
                                            const std::string& b);
bool CTEMPLATE_DLL_DECL IsAbspath(const std::string& path);
bool CTEMPLATE_DLL_DECL IsDirectory(const std::string& path);   // ends in "/"?
void CTEMPLATE_DLL_DECL NormalizeDirectory(std::string* dir);   // appends /
std::string CTEMPLATE_DLL_DECL Basename(const std::string& path);
}

}

#endif  // TEMPLATE_TEMPLATE_PATHOPS_H__

==> ctemplate-0.94.tar.gz: ctemplate-0.94/src/windows/google/template_pathops.h <==
// Copyright (c) 2007, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// ---
// Author: Craig Silverstein

#ifndef TEMPLATE_TEMPLATE_PATHOPS_H_
#define TEMPLATE_TEMPLATE_PATHOPS_H_

#include <string>

// These functions are all for internal use (hence the extra
// namespace), so no need to worry about dll-exporting for windows.

// NOTE: if you are statically linking the template library into your binary
// (rather than using the template .dll), set '/D CTEMPLATE_DLL_DECL='
// as a compiler flag in your project file to turn off the dllimports.
#ifndef CTEMPLATE_DLL_DECL
# define CTEMPLATE_DLL_DECL  __declspec(dllimport)
#endif

namespace google {

namespace ctemplate {

extern CTEMPLATE_DLL_DECL const char kCWD[];       // equivalent to "./"
extern CTEMPLATE_DLL_DECL const char kRootdir[];   // equivalent to "/"

std::string CTEMPLATE_DLL_DECL PathJoin(const std::string& a,
                                            const std::string& b);
bool CTEMPLATE_DLL_DECL IsAbspath(const std::string& path);
bool CTEMPLATE_DLL_DECL IsDirectory(const std::string& path);   // ends in "/"?
void CTEMPLATE_DLL_DECL NormalizeDirectory(std::string* dir);   // appends /
std::string CTEMPLATE_DLL_DECL Basename(const std::string& path);
}

}

#endif  // TEMPLATE_TEMPLATE_PATHOPS_H_
